==> tapi-yandex-direct-2020.12.14.tar.gz: tapi-yandex-direct-2020.12.14/tapi_yandex_direct/resource_mapping.py <==
# coding: utf-8

RESOURCE_MAPPING_V5 = {
    "adextensions": {
        "resource": "json/v5/adextensions",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/adextensions/adextensions-docpage/",
    },
    "adgroups": {
        "resource": "json/v5/adgroups",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/adgroups/adgroups-docpage/",
    },
    "adimages": {
        "resource": "json/v5/adimages",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/adimages/adimages-docpage/",
    },
    "ads": {
        "resource": "json/v5/ads",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/ads/ads-docpage/",
    },
    "agencyclients": {
        "resource": "json/v5/agencyclients",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/agencyclients/agencyclients-docpage/",
    },
    "audiencetargets": {
        "resource": "json/v5/audiencetargets",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/audiencetargets/audiencetargets-docpage/",
    },
    "bids": {
        "resource": "json/v5/bids",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/bids/bids-docpage/",
    },
    "bidmodifiers": {
        "resource": "json/v5/bidmodifiers",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/bidmodifiers/bidmodifiers-docpage/",
    },
    "campaigns": {
        "resource": "json/v5/campaigns",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/campaigns/campaigns-docpage/",
    },
    "changes": {
        "resource": "json/v5/changes",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/changes/changes-docpage/",
    },
    "clients": {
        "resource": "json/v5/clients",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/clients/clients-docpage/",
    },
    "creatives": {
        "resource": "json/v5/creatives",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/creatives/creatives-docpage/",
    },
    "dictionaries": {
        "resource": "json/v5/dictionaries",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/dictionaries/dictionaries-docpage/",
    },
    "dynamicads": {
        "resource": "json/v5/dynamictextadtargets",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/dynamictextadtargets/dynamictextadtargets-docpage/",
    },
    "keywordbids": {
        "resource": "json/v5/keywordbids",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/keywordbids/keywordbids-docpage/",
    },
    "keywords": {
        "resource": "json/v5/keywords",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/keywords/keywords-docpage/",
    },
    "keywordsresearch": {
        "resource": "json/v5/keywordsresearch",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/keywordsresearch/keywordsresearch-docpage/",
    },
    "leads": {
        "resource": "json/v5/leads",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/leads/leads-docpage/",
    },
    "retargeting": {
        "resource": "json/v5/retargetinglists",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/retargetinglists/retargetinglists-docpage/",
    },
    "sitelinks": {
        "resource": "json/v5/sitelinks",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/sitelinks/sitelinks-docpage/",
    },
    "vcards": {
        "resource": "json/v5/vcards",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/vcards/vcards-docpage/",
    },
    "turbopages": {
        "resource": "json/v5/turbopages",
        "docs": "https://yandex.ru/dev/direct/doc/ref-v5/turbopages/turbopages-docpage/",
    },
    "negativekeywordsharedsets": {
        "resource": "json/v5/negativekeywordsharedsets",
        "docs": "https://yandex.ru/dev/direct/doc/ref-v5/negativekeywordsharedsets/negativekeywordsharedsets-docpage/",
    },
    "reports": {
        "resource": "json/v5/reports",
        "docs": "https://yandex.ru/dev/direct/doc/reports/reports-docpage/",
    },
}

RESOURCE_MAPPING_OAUTH = {
    "debugtoken": {
        "resource": "oauth.yandex.ru/authorize?response_type=token&client_id={client_id}",
        "docs": "https://yandex.ru/dev/direct/doc/dg/concepts/auth-token-docpage/",
    },
}

==> tapi-yandex-direct-2021.5.2.tar.gz: tapi-yandex-direct-2021.5.2/tapi_yandex_direct/resource_mapping.py <==

RESOURCE_MAPPING_V5 = {
    "adextensions": {
        "resource": "json/v5/adextensions",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/adextensions/adextensions-docpage/",
    },
    "adgroups": {
        "resource": "json/v5/adgroups",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/adgroups/adgroups-docpage/",
    },
    "adimages": {
        "resource": "json/v5/adimages",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/adimages/adimages-docpage/",
    },
    "ads": {
        "resource": "json/v5/ads",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/ads/ads-docpage/",
    },
    "agencyclients": {
        "resource": "json/v5/agencyclients",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/agencyclients/agencyclients-docpage/",
    },
    "audiencetargets": {
        "resource": "json/v5/audiencetargets",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/audiencetargets/audiencetargets-docpage/",
    },
    "bids": {
        "resource": "json/v5/bids",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/bids/bids-docpage/",
    },
    "bidmodifiers": {
        "resource": "json/v5/bidmodifiers",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/bidmodifiers/bidmodifiers-docpage/",
    },
    "campaigns": {
        "resource": "json/v5/campaigns",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/campaigns/campaigns-docpage/",
    },
    "changes": {
        "resource": "json/v5/changes",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/changes/changes-docpage/",
    },
    "clients": {
        "resource": "json/v5/clients",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/clients/clients-docpage/",
    },
    "creatives": {
        "resource": "json/v5/creatives",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/creatives/creatives-docpage/",
    },
    "dictionaries": {
        "resource": "json/v5/dictionaries",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/dictionaries/dictionaries-docpage/",
    },
    "dynamicads": {
        "resource": "json/v5/dynamictextadtargets",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/dynamictextadtargets/dynamictextadtargets-docpage/",
    },
    "keywordbids": {
        "resource": "json/v5/keywordbids",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/keywordbids/keywordbids-docpage/",
    },
    "keywords": {
        "resource": "json/v5/keywords",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/keywords/keywords-docpage/",
    },
    "keywordsresearch": {
        "resource": "json/v5/keywordsresearch",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/keywordsresearch/keywordsresearch-docpage/",
    },
    "leads": {
        "resource": "json/v5/leads",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/leads/leads-docpage/",
    },
    "retargeting": {
        "resource": "json/v5/retargetinglists",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/retargetinglists/retargetinglists-docpage/",
    },
    "sitelinks": {
        "resource": "json/v5/sitelinks",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/sitelinks/sitelinks-docpage/",
    },
    "vcards": {
        "resource": "json/v5/vcards",
        "docs": "https://tech.yandex.ru/direct/doc/ref-v5/vcards/vcards-docpage/",
    },
    "turbopages": {
        "resource": "json/v5/turbopages",
        "docs": "https://yandex.ru/dev/direct/doc/ref-v5/turbopages/turbopages-docpage/",
    },
    "negativekeywordsharedsets": {
        "resource": "json/v5/negativekeywordsharedsets",
        "docs": "https://yandex.ru/dev/direct/doc/ref-v5/negativekeywordsharedsets/negativekeywordsharedsets-docpage/",
    },
    "reports": {
        "resource": "json/v5/reports",
        "docs": "https://yandex.ru/dev/direct/doc/reports/reports-docpage/",
    },
    "debugtoken": {
        "resource": "oauth.yandex.ru/authorize?response_type=token&client_id={client_id}",
        "docs": "https://yandex.ru/dev/direct/doc/dg/concepts/auth-token-docpage/",
    },
    "feeds": {
        "resource": "json/v5/feeds",
        "docs": "https://yandex.ru/dev/direct/doc/ref-v5/feeds/feeds.html",
    },
    "smartadtargets": {
        "resource": "json/v5/smartadtargets",
        "docs": "https://yandex.ru/dev/direct/doc/ref-v5/smartadtargets/smartadtargets.html",
    },
    "businesses": {
        "resource": "json/v5/businesses",
        "docs": "https://yandex.ru/dev/direct/doc/ref-v5/businesses/businesses.html",
    },
}
